/******************************************************************************/
/* Gesto de Projetos
/******************************************************************************/
/*
/* Nome: ETL_MPSBR_F
/*
/* Criao:
/*    05/05/2009 - Ana Carolina e Newton N. Santos
/*
/* Manuteno:
/*    --/--/---- - Xxxxxx
/*
/*  @c:\compartilhada\0000_GEPSTPO_ETL_MPSBR_F.SQL
/*  EXEC ETL_MPSBR_F('9999', '000000V507', 'FIM_20090520160000')
/******************************************************************************/




create or replace PROCEDURE ETL_MPSBR_F ( P_CDFILIAL    IN FILIAL.CDFILIAL%TYPE,
                        P_CDGRUPOPROJ IN PROJETO.CDGRUPOPROJ%TYPE,
                        P_CDBASELINE  IN ETLCMMMONITPROJ.CDBLINEMONPROJ%TYPE )
IS

  /* Variveis ETL Monit. Projeto */
  V_NRMONITPROJ     ETLCMMMONITPROJ.NRMONITPROJ%TYPE;

  /* Variveis ETL Indicadores */
  V_NRCMMINDICADOR  ETLCMMINDICADOR.NRCMMINDICADOR%TYPE;

  /* Variveis de uso geral */
  V_DTMES           VARCHAR2(07);
  V_DTANO           VARCHAR2(04);
  V_DTDIA           VARCHAR2(02);
  V_DTHORA          VARCHAR2(08);

BEGIN

    /* ---- */
    /* INICIO - Rotina para gravao do ETL de monitoramento de projetos */
    /* ---- */

    BEGIN
       SELECT NVL(MAX(TO_NUMBER(NRMONITPROJ)),0)
       INTO   V_NRMONITPROJ
       FROM ETLCMMMONITPROJ;
    EXCEPTION
    WHEN OTHERS THEN
        V_NRMONITPROJ := '0';
    END;

    DELETE FROM ETLCMMMONITPROJ
    WHERE CDFILIAL = P_CDFILIAL
      AND CDGRUPOPROJ = P_CDGRUPOPROJ
      AND CDBLINEMONPROJ = P_CDBASELINE;

    FOR C_MON IN
        (SELECT PR.CDFILIAL,
                PR.CDGRUPOPROJ,
                PR.CDPROJETO,
                NVL(TF.NRBASELINEPR, 'XXX') AS NRBASELINEPR,
                QU.CDPROCESSO||QU.CDQUALIFPROC AS CDQUALIFPROC,
                PR.CDOPERESPRJ,
                1 AS QTSOMAQUALIF,
                TO_CHAR(AP.DTHIAPATIVTA, 'DD/MM/YYYY HH24:MI:SS') AS DTHIAPATIVTA,
                ABS(ROUND((AP.DTHFAPATIVTA-AP.DTHIAPATIVTA)*24*60*60,2)) AS QTTEMPOAPROP
         FROM PROJETO PR, TAREFA TF, PLANATIVTARE PL, APROATIVTARE AP, QUALIFPROC QU
         WHERE PR.CDFILIAL = P_CDFILIAL
           AND PR.CDGRUPOPROJ = P_CDGRUPOPROJ
           AND TF.CDPROJETO = PR.CDPROJETO
           AND QU.CDQUALIFPROC = PL.CDQUALIFPROC
           AND QU.CDPROCESSO = PL.CDPROCESSO
           AND TF.CDFILIAL = PR.CDFILIAL
           AND PL.CDFILIAL = TF.CDFILIAL
           AND PL.NRTAREFA = TF.NRTAREFA
           AND PL.CDFILIAL = AP.CDFILIAL
           AND PL.NRTAREFA = AP.NRTAREFA
           AND PL.NRPLATIVTARE = AP.NRPLATIVTARE
    LOOP
        V_DTANO  := SUBSTR(P_CDBASELINE,5,4);
        V_DTMES  := SUBSTR(P_CDBASELINE,9,2);
        V_DTDIA  := SUBSTR(P_CDBASELINE,11,2);
        V_DTHORA := SUBSTR(P_CDBASELINE,13,2)||':'||SUBSTR(P_CDBASELINE,15,2)||':'||SUBSTR(P_CDBASELINE,17,2);

        V_NRMONITPROJ := V_NRMONITPROJ + 1;

        INSERT INTO ETLCMMMONITPROJ
             (NRMONITPROJ, CDBLINEMONPROJ, CDFILIAL, CDGRUPOPROJ, CDPROJETO, NRBASELINEPR, CDQUALIFPROC, CDOPERGERENPROJ,
              QTSOMAQUALIF, DTHRMONITPROJ, QTTEMPOAPROP, ANMONITPROJ, MEMONITPROJ, DIMONITPROJ, HRMONITPROJ)
        VALUES
              (V_NRMONITPROJ, P_CDBASELINE, C_MON.CDFILIAL, C_MON.CDGRUPOPROJ, C_MON.CDPROJETO, C_MON.NRBASELINEPR,
               C_MON.CDQUALIFPROC, C_MON.CDOPERESPRJ, C_MON.QTSOMAQUALIF, C_MON.DTHIAPATIVTA, C_MON.QTTEMPOAPROP,
               V_DTANO, V_DTMES, V_DTDIA, V_DTHORA);
    END LOOP;

    COMMIT;

    /* ---- */
    /* FIM - Rotina para gravao do ETL de monitoramento de projetos */
    /* ---- */

    /* ---- */
    /* INICIO - Rotina para gravao do ETL de indicadores de projetos */
    /* ---- */

    BEGIN
       SELECT NVL(MAX(TO_NUMBER(NRCMMINDICADOR)),0)
       INTO   V_NRCMMINDICADOR
       FROM ETLCMMINDICADOR;
    EXCEPTION
    WHEN OTHERS THEN
        V_NRCMMINDICADOR := '0';
    END;

    DELETE FROM ETLCMMINDICADOR
    WHERE CDFILIAL = P_CDFILIAL
      AND CDGRUPOPROJ = P_CDGRUPOPROJ
      AND CDBLINEINDIC = P_CDBASELINE;

    FOR C_IND IN
        (SELECT SS.CDFILIAL, SS.CDPROJETO, SS.NRBASELINEPR, SS.CDOPERESPRJ,SS.VRNOTAPROJETO,
                NVL(A.QTTEMPREAL,0) AS ESFORCOREAL,
                NVL(ROUND(B.ESFPREV,2),0)  AS ESFORCOPLAN,
                NVL(ROUND(NVL(B.CUSTOPLANEJADO,0),2),0) AS CUSTOPLAN,
                NVL(ROUND(NVL(A.CUSTOREAL,0),2),0) AS CUSTOREAL,
                NVL(C.TEMPERRO,0) AS TEMPOERRO,
                NVL(D.TEMPOENTREGUE,0) AS TEMPOENTREGUE,
                NVL(E.HORASPRIVER,0) AS HORASPRIVER,
                NVL(F.HORASULTVER,0) AS HORASULTVER,
                NVL(G.QTATIVIMPLDIVER,0) AS QTATIVIMPLDIVER,
                NVL(H.QTTOTALATIV,0) AS QTTOTALATIV,
                NVL(I.QTATIVFORAPRAZ,0) AS QTATIVFORAPRAZ
           FROM (SELECT P.CDFILIAL, P.CDPROJETO, B.NRBASEGRPR AS NRBASELINEPR, P.CDOPERESPRJ, P.VRNOTAPROJETO
                   FROM PROJETO P, BASELINEGRPROJ B
                  WHERE P.CDFILIAL = P_CDFILIAL
                    AND B.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND B.CDGRUPOPROJ = P.CDGRUPOPROJ) SS,

                (SELECT ROUND(SUM(DTHFAPATIVTA - DTHIAPATIVTA)*24,2) AS QTTEMPREAL,
                        SB.CDFILIAL, SB.NRBASELINEPR, SB.CDPROJETO,
                        SUM((DTHFAPATIVTA - DTHIAPATIVTA)*24 * NVL((GC.VRCUSTPADGRC/240),0)) AS CUSTOREAL
                   FROM BASELINEPROJ BS, SOLIBASELINE SB, SOLISERV SS, TAREFA TF,
                        APROATIVTARE AP, OPERADOR OP, CARGO CA, GRUPO_CARGO GC,
                        PROCESSO PO, PLANATIVTARE PL, PROJETO PJ
                  WHERE PJ.CDFILIAL = P_CDFILIAL
                    AND PJ.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND PJ.CDPROJETO = SB.CDPROJETO
                    AND PJ.CDFILIAL = SB.CDFILIAL
                    AND SB.CDFILIAL = BS.CDFILIAL
                    AND SB.CDPROJETO = BS.CDPROJETO
                    AND SB.NRBASELINEPR = BS.NRBASELINEPR
                    AND SB.CDFILIAL = SS.CDFILIAL
                    AND SB.NRSOLISERV = SS.NRSOLISERV
                    AND SB.CDFILIAL = TF.CDFILIAL
                    AND SB.NRSOLISERV = TF.NRSOLISERV
                    AND TF.CDFILIAL = AP.CDFILIAL
                    AND TF.NRTAREFA = AP.NRTAREFA
                    AND AP.CDOPERADOR = OP.CDOPERADOR
                    AND OP.CDCARGO = CA.CDCARGO
                    AND CA.CDGRUPOCARGO = GC.CDGRUPOCARGO
                    AND PL.NRPLATIVTARE = AP.NRPLATIVTARE
                    AND PL.NRTAREFA = AP.NRTAREFA
                    AND PL.CDFILIAL = AP.CDFILIAL
                    AND PL.CDPROCESSO = PO.CDPROCESSO
                  GROUP BY SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR) A,

                (SELECT TA.CDFILIAL, SO.NRBASELINEPR, SO.CDPROJETO, SUM(PL.QTTEMPLAITAR) AS ESFPREV, SUM(PL.QTTEMPLAITAR * NVL((GC.VRCUSTPADGRC/240),0)) AS CUSTOPLANEJADO
                   FROM PLANATIVTARE PL, TAREFA TA, SOLIBASELINE SO, OPERADOR OP,
                        CARGO CA, GRUPO_CARGO GC, PROCESSO PC, PROJETO PJ
                  WHERE PJ.CDFILIAL = P_CDFILIAL
                    AND PJ.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND SO.CDFILIAL = PJ.CDFILIAL
                    AND SO.CDPROJETO = PJ.CDPROJETO
                    AND TA.CDFILIAL = PL.CDFILIAL
                    AND TA.NRTAREFA = PL.NRTAREFA
                    AND TA.CDFILIAL = SO.CDFILIAL
                    AND TA.NRSOLISERV = SO.NRSOLISERV
                    AND PL.CDOPERRESP = OP.CDOPERADOR
                    AND OP.CDCARGO = CA.CDCARGO
                    AND CA.CDGRUPOCARGO = GC.CDGRUPOCARGO
                    AND PL.CDPROCESSO = PC.CDPROCESSO
                    AND ((PL.CDPROCESSO = '0000011045') OR (PL.CDPROCESSO = '0000011055') OR (PL.CDPROCESSO = '0000011048') OR (PL.CDPROCESSO = '0000000663'))
                  GROUP BY TA.CDFILIAL, SO.CDPROJETO, SO.NRBASELINEPR) B,

                (SELECT SS.CDFILIAL, SS.CDPROJETO, SS.NRBASELINEPR, SUM(AP.DTFAPATIVTAR - AP.DTIAPATIVTAR) * 24 AS TEMPERRO
                   FROM APROATIVTARE AP, PLANATIVTARE PL, TAREFA TF, SOLIBASELINE SS, PROJETO PJ
                  WHERE PJ.CDFILIAL = P_CDFILIAL
                    AND PJ.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND PL.CDFILIAL = PJ.CDFILIAL
                    AND SS.CDPROJETO = PJ.CDPROJETO
                    AND PL.CDFILIAL = AP.CDFILIAL
                    AND PL.NRTAREFA = AP.NRTAREFA
                    AND PL.NRPLATIVTARE = AP.NRPLATIVTARE
                    AND PL.CDFILIAL = TF.CDFILIAL
                    AND PL.NRTAREFA = TF.NRTAREFA
                    AND TF.NRSOLISERV = SS.NRSOLISERV
                    AND (INSTR('_0000010196_0000011633_0000010706_0000010712_0000011329_', PL.CDPROCESSO) > 0)
                  GROUP BY SS.CDFILIAL, SS.CDPROJETO, SS.NRBASELINEPR) C,

                (SELECT SUM(PL.QTTEMPLAITAR) AS TEMPOENTREGUE, PL.NRBASELINECONC, PL.CDPROJCONCLUSAO, PL.CDFILIAL
                   FROM PLANATIVTARE PL, PROJETO PJ
                  WHERE PJ.CDFILIAL = P_CDFILIAL
                    AND PJ.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND PL.CDFILIAL = PJ.CDFILIAL
                    AND PL.CDPROJCONCLUSAO = PJ.CDPROJETO
                    AND PL.IDSITATIVTAR = 'C'
                 GROUP BY PL.CDFILIAL, PL.CDPROJCONCLUSAO, PL.NRBASELINECONC) D,

                (SELECT SUM(NVL(CR.NRDIASITCRPJ,0)) AS HORASPRIVER, CR.CDFILIAL, CR.CDPROJETO, CR.NRBASELINEPR
                   FROM CRONOPROJETO CR, PROJETO PJ
                  WHERE PJ.CDFILIAL = P_CDFILIAL
                    AND PJ.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND CR.CDFILIAL = PJ.CDFILIAL
                    AND CR.CDPROJETO = PJ.CDPROJETO
                    AND CR.CDNIVELITPRJ = '3'
                    AND CR.CDVERCRONPRJ = (SELECT MIN(CP.CDVERCRONPRJ)
                                             FROM CRONOPROJETO CP
                                            WHERE CR.CDFILIAL = CP.CDFILIAL
                                              AND CR.CDPROJETO = CP.CDPROJETO
                                              AND CR.NRBASELINEPR = CP.NRBASELINEPR)
                  GROUP BY CR.CDFILIAL, CR.CDPROJETO, CR.NRBASELINEPR) E,

                (SELECT SUM(NVL(CR.NRDIASITCRPJ,0)) AS HORASULTVER, CR.CDFILIAL, CR.CDPROJETO, CR.NRBASELINEPR
                   FROM CRONOPROJETO CR, PROJETO PJ
                  WHERE PJ.CDFILIAL = P_CDFILIAL
                    AND PJ.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND CR.CDFILIAL = PJ.CDFILIAL
                    AND CR.CDPROJETO = PJ.CDPROJETO
                    AND CR.CDNIVELITPRJ = '3'
                    AND CR.CDVERCRONPRJ = (SELECT MAX(CP.CDVERCRONPRJ)
                                             FROM CRONOPROJETO CP
                                            WHERE CR.CDFILIAL = CP.CDFILIAL
                                              AND CR.CDPROJETO = CP.CDPROJETO
                                              AND CR.NRBASELINEPR = CP.NRBASELINEPR)
                  GROUP BY CR.CDFILIAL, CR.CDPROJETO, CR.NRBASELINEPR) F,

                (SELECT COUNT(*) AS QTATIVIMPLDIVER, SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR
                   FROM PLANATIVTARE PL, TAREFA TF, SOLIBASELINE SB, PROJETO PR
                  WHERE SB.CDFILIAL = TF.CDFILIAL
                    AND SB.NRSOLISERV = TF.NRSOLISERV
                    AND TF.CDFILIAL = PL.CDFILIAL
                    AND TF.NRTAREFA = PL.NRTAREFA
                    AND SB.CDFILIAL = PR.CDFILIAL
                    AND SB.CDPROJETO = PR.CDPROJETO
                    AND PR.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND PR.CDFILIAL = P_CDFILIAL
                    AND PL.CDPROCESSO IN ('0000011570', '0000011571')
                  GROUP BY SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR)G,

                (SELECT COUNT(*) AS QTTOTALATIV, SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR
                   FROM PLANATIVTARE PL, TAREFA TF, SOLIBASELINE SB, PROJETO PR
                  WHERE SB.CDFILIAL = TF.CDFILIAL
                    AND SB.NRSOLISERV = TF.NRSOLISERV
                    AND TF.CDFILIAL = PL.CDFILIAL
                    AND TF.NRTAREFA = PL.NRTAREFA
                    AND SB.CDFILIAL = PR.CDFILIAL
                    AND SB.CDPROJETO = PR.CDPROJETO
                    AND PR.CDGRUPOPROJ = P_CDGRUPOPROJ
                    AND PR.CDFILIAL = P_CDFILIAL
                    AND PL.CDPROCESSO IN ('0000011045', '0000011054', '0000011077', '0000011080', '0000011083', '000001262', '0000011264')
                  GROUP BY SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR) H,

                 (SELECT SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR, COUNT(*) AS QTATIVFORAPRAZ
                    FROM DATAGRPROJETO DT, GRUPOPROJETO GR, SOLIBASELINE SB, TAREFA TF, PLANATIVTARE PL, PROJETO PR
                   WHERE DT.CDGRUPOPROJ = GR.CDGRUPOPROJ
                     AND DT.IDDATAGRPROJ ='DEF'
                     AND GR.CDGRUPOPROJ = PR.CDGRUPOPROJ
                     AND SB.CDFILIAL = PR.CDFILIAL
                     AND SB.CDPROJETO = PR.CDPROJETO
                     AND SB.IDSITUSOLBASELI = 'I'
                     AND SB.CDFILIAL = TF.CDFILIAL
                     AND SB.NRSOLISERV = TF.NRSOLISERV
                     AND TF.CDFILIAL = PL.CDFILIAL
                     AND TF.NRTAREFA = PL.NRTAREFA
                     AND PR.CDGRUPOPROJ = P_CDGRUPOPROJ
                     AND PR.CDFILIAL = P_CDFILIAL
                     AND PL.DTINCATIVTAR >= DT.DTFINGRPROJ
                     AND PL.CDPROCESSO IN ('0000011045', '0000011054', '0000011077', '0000011080', '0000011083', '0000011262', '0000011264')
                   GROUP BY SB.CDFILIAL, SB.CDPROJETO, SB.NRBASELINEPR) I
         WHERE SS.CDFILIAL = A.CDFILIAL (+)
           AND SS.CDPROJETO = A.CDPROJETO (+)
           AND SS.NRBASELINEPR = A.NRBASELINEPR (+)
           AND SS.CDFILIAL = B.CDFILIAL (+)
           AND SS.CDPROJETO = B.CDPROJETO (+)
           AND SS.NRBASELINEPR = B.NRBASELINEPR (+)
           AND SS.CDFILIAL = C.CDFILIAL (+)
           AND SS.CDPROJETO = C.CDPROJETO (+)
           AND SS.NRBASELINEPR = C.NRBASELINEPR (+)
           AND SS.CDFILIAL = D.CDFILIAL (+)
           AND SS.CDPROJETO = D.CDPROJCONCLUSAO (+)
           AND SS.NRBASELINEPR = D.NRBASELINECONC (+)
           AND SS.CDFILIAL = E.CDFILIAL (+)
           AND SS.CDPROJETO = E.CDPROJETO (+)
           AND SS.NRBASELINEPR = E.NRBASELINEPR (+)
           AND SS.CDFILIAL = F.CDFILIAL (+)
           AND SS.CDPROJETO = F.CDPROJETO (+)
           AND SS.NRBASELINEPR = F.NRBASELINEPR (+)
           AND SS.CDFILIAL = G.CDFILIAL (+)
           AND SS.CDPROJETO = G.CDPROJETO (+)
           AND SS.NRBASELINEPR = G.NRBASELINEPR (+)
           AND SS.CDFILIAL = H.CDFILIAL (+)
           AND SS.CDPROJETO = H.CDPROJETO (+)
           AND SS.NRBASELINEPR = H.NRBASELINEPR (+)
           AND SS.CDFILIAL = I.CDFILIAL (+)
           AND SS.CDPROJETO = I.CDPROJETO (+)
           AND SS.NRBASELINEPR = I.NRBASELINEPR (+))
    LOOP
        V_DTANO  := SUBSTR(P_CDBASELINE,5,4);
        V_DTMES  := SUBSTR(P_CDBASELINE,9,2);
        V_DTDIA  := SUBSTR(P_CDBASELINE,11,2);
        V_DTHORA := SUBSTR(P_CDBASELINE,13,2)||':'||SUBSTR(P_CDBASELINE,15,2)||':'||SUBSTR(P_CDBASELINE,17,2);

        V_NRCMMINDICADOR := V_NRCMMINDICADOR + 1;

        INSERT INTO ETLCMMINDICADOR
             (NRCMMINDICADOR, CDBLINEINDIC, CDFILIAL, CDGRUPOPROJ, CDPROJETO, NRBASELINEPR, CDOPERGERENPROJ,
              QTESFORCOREAL, QTESFORCOPLAN, VRCUSTOPLAN, VRCUSTOREAL, QTTEMPOERRO, QTTEMPOENTREGUE,
              QTHORASPRIVER, QTHORASULTVER, ANCMMINDICADOR, MECMMINDICADOR, DICMMINDICADOR, HRCMMINDICADOR,VRNOTAPROJ,
              QTATIVIMPLDIVER, QTTOTALATIV, QTATIVFORAPRAZ)
        VALUES
             (V_NRCMMINDICADOR, P_CDBASELINE, C_IND.CDFILIAL, P_CDGRUPOPROJ, C_IND.CDPROJETO, C_IND.NRBASELINEPR, C_IND.CDOPERESPRJ,
              C_IND.ESFORCOREAL, C_IND.ESFORCOPLAN, C_IND.CUSTOPLAN, C_IND.CUSTOREAL, C_IND.TEMPOERRO, C_IND.TEMPOENTREGUE,
              C_IND.HORASPRIVER, C_IND.HORASULTVER, V_DTANO, V_DTMES, V_DTDIA, V_DTHORA, C_IND.VRNOTAPROJETO, C_IND.QTATIVIMPLDIVER,
              C_IND.QTTOTALATIV, C_IND.QTATIVFORAPRAZ);
    END LOOP;

    COMMIT;

    /* ---- */
    /* FIM - Rotina para gravao do ETL de indicadores de projetos */
    /* ---- */

END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ETL_MPSBR_F','5.07.014'); END;
/

